@@ -69,6 +69,7 @@ def main():
 BUILDER_OPTS = {
     "html": "html",
     "dirhtml": "dirhtml",
+    "singlehtml": "singlehtml",
     "pdfhtml": "singlehtml",
     "latex": "latex",
     "pdflatex": "latex",
@@ -271,6 +272,8 @@ def build(
         OUTPUT_PATH = BUILD_PATH.joinpath("latex")
     elif builder in ["dirhtml"]:
         OUTPUT_PATH = BUILD_PATH.joinpath("dirhtml")
+    elif builder in ["singlehtml"]:
+        OUTPUT_PATH = BUILD_PATH.joinpath("singlehtml")
     elif builder in ["custom"]:
         OUTPUT_PATH = BUILD_PATH.joinpath(custom_builder)
         BUILDER_OPTS["custom"] = custom_builder
