@@ -150,7 +150,7 @@ def get_final_config(
     }
 
     if sphinx_config.get("use_jupyterbook_latex"):
-        sphinx_config["extensions"].append("jupyterbook_latex")
+        sphinx_config["extensions"].append("sphinx_jupyterbook_latex")
 
     # finally merge in CLI configuration
     _recursive_update(sphinx_config, cli_config or {})
@@ -234,6 +234,7 @@ def yaml_to_sphinx(yaml: dict):
             ("html_favicon", "favicon"),
             ("html_baseurl", "baseurl"),
             ("comments_config", "comments"),
+            ("use_multitoc_numbering", "use_multitoc_numbering"),
         ]:
             if yml_key in html:
                 sphinx_config[spx_key] = html[yml_key]
